@@ -1175,6 +1175,7 @@
     var MessageType;
     (function (MessageType) {
         MessageType["UI_GET_DATA"] = "ui-get-data";
+        MessageType["UI_GET_DEVTOOLS_DATA"] = "ui-get-devtools-data";
         MessageType["UI_SUBSCRIBE_TO_CHANGES"] = "ui-subscribe-to-changes";
         MessageType["UI_UNSUBSCRIBE_FROM_CHANGES"] =
             "ui-unsubscribe-from-changes";
@@ -1618,7 +1619,7 @@
             const c = $color[i];
             if ((c >= "0" && c <= "9") || c === "." || c === "+" || c === "-") {
                 isMining = true;
-            } else if (isMining && (c === " " || c === ",")) {
+            } else if (isMining && (c === " " || c === "," || c === "/")) {
                 numbers.push($color.substring(prevPos, i));
                 isMining = false;
                 prevPos = i + 1;
@@ -2356,7 +2357,7 @@
         );
     }
 
-    const simpleIPV6Regex = /\[[0-9:a-zA-Z]*?\]/;
+    const simpleIPV6Regex = /\[[0-9:a-zA-Z]+?\]/;
     function isIPV6(url) {
         const openingBracketIndex = simpleIPV6Regex.exec(url);
         if (!openingBracketIndex) {
@@ -2578,6 +2579,9 @@
         async getData() {
             return await this.sendRequest(MessageType.UI_GET_DATA);
         }
+        async getDevToolsData() {
+            return await this.sendRequest(MessageType.UI_GET_DEVTOOLS_DATA);
+        }
         subscribeToChanges(callback) {
             this.changeSubscribers.add(callback);
             if (this.changeSubscribers.size === 1) {
